@@ -46,6 +46,7 @@
 #include "scripts.h"
 #include "sessionmanager.h"
 #include "closedwindowsmanager.h"
+#include "protocolhandlermanager.h"
 #include "../config.h"
 
 #include <QWebEngineSettings>
@@ -65,6 +66,7 @@
 #include <QWebEngineDownloadItem>
 #include <QWebEngineScriptCollection>
 #include <QRegularExpression>
+#include <QtWebEngineWidgetsVersion>
 
 #ifdef Q_OS_WIN
 #include <QtWin>
@@ -86,23 +88,24 @@ MainApplication::MainApplication(int &argc, char** argv)
     , m_isPortable(false)
     , m_isClosing(false)
     , m_isStartingAfterCrash(false)
-    , m_history(0)
-    , m_bookmarks(0)
-    , m_autoFill(0)
-    , m_cookieJar(0)
-    , m_plugins(0)
-    , m_browsingLibrary(0)
-    , m_networkManager(0)
-    , m_restoreManager(0)
-    , m_sessionManager(0)
-    , m_downloadManager(0)
-    , m_userAgentManager(0)
-    , m_searchEnginesManager(0)
-    , m_closedWindowsManager(0)
-    , m_html5PermissionsManager(0)
-    , m_desktopNotifications(0)
-    , m_webProfile(0)
-    , m_autoSaver(0)
+    , m_history(nullptr)
+    , m_bookmarks(nullptr)
+    , m_autoFill(nullptr)
+    , m_cookieJar(nullptr)
+    , m_plugins(nullptr)
+    , m_browsingLibrary(nullptr)
+    , m_networkManager(nullptr)
+    , m_restoreManager(nullptr)
+    , m_sessionManager(nullptr)
+    , m_downloadManager(nullptr)
+    , m_userAgentManager(nullptr)
+    , m_searchEnginesManager(nullptr)
+    , m_closedWindowsManager(nullptr)
+    , m_protocolHandlerManager(nullptr)
+    , m_html5PermissionsManager(nullptr)
+    , m_desktopNotifications(nullptr)
+    , m_webProfile(nullptr)
+    , m_autoSaver(nullptr)
 #if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
     , m_registerQAppAssociation(0)
 #endif
@@ -110,15 +113,15 @@ MainApplication::MainApplication(int &argc, char** argv)
     setAttribute(Qt::AA_UseHighDpiPixmaps);
     setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
 
-    setApplicationName(QLatin1String("falkon"));
-    setOrganizationDomain(QLatin1String("org.kde"));
+    setApplicationName(QStringLiteral("falkon"));
+    setOrganizationDomain(QStringLiteral("org.kde"));
     setWindowIcon(QIcon::fromTheme(QSL("falkon"), QIcon(QSL(":icons/falkon.svg"))));
     setDesktopFileName(QSL("org.kde.falkon"));
 
 #ifdef GIT_REVISION
     setApplicationVersion(QSL("%1 (%2)").arg(Qz::VERSION, GIT_REVISION));
 #else
-    setApplicationVersion(Qz::VERSION);
+    setApplicationVersion(QString::fromLatin1(Qz::VERSION));
 #endif
 
     // Set fallback icon theme (eg. on Windows/Mac)
@@ -128,7 +131,7 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     // QSQLITE database plugin is required
     if (!QSqlDatabase::isDriverAvailable(QSL("QSQLITE"))) {
-        QMessageBox::critical(0, QSL("Error"), QSL("Qt SQLite database plugin is not available. Please install it and restart the application."));
+        QMessageBox::critical(nullptr, QSL("Error"), QSL("Qt SQLite database plugin is not available. Please install it and restart the application."));
         m_isClosing = true;
         return;
     }
@@ -164,18 +167,18 @@ MainApplication::MainApplication(int &argc, char** argv)
                 m_isPortable = true;
                 break;
             case Qz::CL_NewTab:
-                messages.append(QLatin1String("ACTION:NewTab"));
+                messages.append(QStringLiteral("ACTION:NewTab"));
                 m_postLaunchActions.append(OpenNewTab);
                 break;
             case Qz::CL_NewWindow:
-                messages.append(QLatin1String("ACTION:NewWindow"));
+                messages.append(QStringLiteral("ACTION:NewWindow"));
                 break;
             case Qz::CL_ToggleFullScreen:
-                messages.append(QLatin1String("ACTION:ToggleFullScreen"));
+                messages.append(QStringLiteral("ACTION:ToggleFullScreen"));
                 m_postLaunchActions.append(ToggleFullScreen);
                 break;
             case Qz::CL_ShowDownloadManager:
-                messages.append(QLatin1String("ACTION:ShowDownloadManager"));
+                messages.append(QStringLiteral("ACTION:ShowDownloadManager"));
                 m_postLaunchActions.append(OpenDownloadManager);
                 break;
             case Qz::CL_StartPrivateBrowsing:
@@ -199,6 +202,9 @@ MainApplication::MainApplication(int &argc, char** argv)
             case Qz::CL_ExitAction:
                 m_isClosing = true;
                 return;
+            case Qz::CL_WMClass:
+                m_wmClass = pair.text.toUtf8();
+                break;
             default:
                 break;
             }
@@ -217,14 +223,14 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     // Don't start single application in private browsing
     if (!isPrivate()) {
-        QString appId = QLatin1String("FalkonWebBrowser");
+        QString appId = QStringLiteral("org.kde.Falkon");
 
         if (isPortable()) {
-            appId.append(QLatin1String("Portable"));
+            appId.append(QLatin1String(".Portable"));
         }
 
         if (isTestModeEnabled()) {
-            appId.append(QSL("TestMode"));
+            appId.append(QSL(".TestMode"));
         }
 
         if (newInstance) {
@@ -235,7 +241,7 @@ MainApplication::MainApplication(int &argc, char** argv)
                 // Generate unique appId so it is possible to start more separate instances
                 // of the same profile. It is dangerous to run more instances of the same profile,
                 // but if the user wants it, we should allow it.
-                appId.append(startProfile + QString::number(QDateTime::currentMSecsSinceEpoch()));
+                appId.append(QLatin1Char('.') + startProfile + QString::number(QDateTime::currentMSecsSinceEpoch()));
             }
         }
 
@@ -244,7 +250,7 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     // If there is nothing to tell other instance, we need to at least wake it
     if (messages.isEmpty()) {
-        messages.append(QLatin1String(" "));
+        messages.append(QStringLiteral(" "));
     }
 
     if (isRunning()) {
@@ -285,7 +291,7 @@ MainApplication::MainApplication(int &argc, char** argv)
     if (!isPrivate() && !isTestModeEnabled()) {
         m_sessionManager = new SessionManager(this);
         m_autoSaver = new AutoSaver(this);
-        connect(m_autoSaver, SIGNAL(save()), m_sessionManager, SLOT(autoSaveLastSession()));
+        connect(m_autoSaver, &AutoSaver::save, m_sessionManager, &SessionManager::autoSaveLastSession);
 
         Settings settings;
         settings.beginGroup(QSL("SessionRestore"));
@@ -313,6 +319,7 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     m_plugins = new PluginProxy(this);
     m_autoFill = new AutoFill(this);
+    mApp->protocolHandlerManager();
 
     if (!noAddons)
         m_plugins->loadPlugins();
@@ -320,7 +327,7 @@ MainApplication::MainApplication(int &argc, char** argv)
     BrowserWindow* window = createWindow(Qz::BW_FirstAppWindow, startUrl);
     connect(window, SIGNAL(startingCompleted()), this, SLOT(restoreOverrideCursor()));
 
-    connect(this, SIGNAL(focusChanged(QWidget*,QWidget*)), this, SLOT(onFocusChanged()));
+    connect(this, &QApplication::focusChanged, this, &MainApplication::onFocusChanged);
 
     if (!isPrivate() && !isTestModeEnabled()) {
 #ifndef DISABLE_CHECK_UPDATES
@@ -346,11 +353,18 @@ MainApplication::MainApplication(int &argc, char** argv)
         }
     }
 
-    QTimer::singleShot(0, this, SLOT(postLaunch()));
+    QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, DataPaths::currentProfilePath());
+
+    connect(this, SIGNAL(messageReceived(QString)), this, SLOT(messageReceived(QString)));
+    connect(this, &QCoreApplication::aboutToQuit, this, &MainApplication::saveSettings);
+
+    QTimer::singleShot(0, this, &MainApplication::postLaunch);
 }
 
 MainApplication::~MainApplication()
 {
+    m_isClosing = true;
+
     IconProvider::instance()->saveIconsToDatabase();
 
     // Wait for all QtConcurrent jobs to finish
@@ -415,7 +429,7 @@ BrowserWindow* MainApplication::createWindow(Qz::BrowserWindowType type, const Q
     }
 
     BrowserWindow* window = new BrowserWindow(type, startUrl);
-    connect(window, SIGNAL(destroyed(QObject*)), this, SLOT(windowDestroyed(QObject*)));
+    connect(window, &QObject::destroyed, this, &MainApplication::windowDestroyed);
 
     m_windows.prepend(window);
     return window;
@@ -492,6 +506,11 @@ void MainApplication::setProxyStyle(ProxyStyle *style)
     setStyle(style);
 }
 
+QByteArray MainApplication::wmClass() const
+{
+    return m_wmClass;
+}
+
 History* MainApplication::history()
 {
     if (!m_history) {
@@ -581,6 +600,14 @@ ClosedWindowsManager* MainApplication::closedWindowsManager()
     return m_closedWindowsManager;
 }
 
+ProtocolHandlerManager *MainApplication::protocolHandlerManager()
+{
+    if (!m_protocolHandlerManager) {
+        m_protocolHandlerManager = new ProtocolHandlerManager(this);
+    }
+    return m_protocolHandlerManager;
+}
+
 HTML5PermissionsManager* MainApplication::html5PermissionsManager()
 {
     if (!m_html5PermissionsManager) {
@@ -656,7 +683,7 @@ void MainApplication::startPrivateBrowsing(const QUrl &startUrl)
 
 void MainApplication::reloadUserStyleSheet()
 {
-    const QString userCssFile = Settings().value("Web-Browser-Settings/userStyleSheet", QString()).toString();
+    const QString userCssFile = Settings().value(QSL("Web-Browser-Settings/userStyleSheet"), QString()).toString();
     setUserStyleSheet(userCssFile);
 }
 
@@ -718,11 +745,6 @@ void MainApplication::postLaunch()
         getWindow()->toggleFullScreen();
     }
 
-    QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, DataPaths::currentProfilePath());
-
-    connect(this, SIGNAL(messageReceived(QString)), this, SLOT(messageReceived(QString)));
-    connect(this, SIGNAL(aboutToQuit()), this, SLOT(saveSettings()));
-
     createJumpList();
     initPulseSupport();
 
@@ -762,19 +784,19 @@ void MainApplication::saveSettings()
     m_isClosing = true;
 
     Settings settings;
-    settings.beginGroup("SessionRestore");
-    settings.setValue("isRunning", false);
-    settings.setValue("isRestoring", false);
+    settings.beginGroup(QSL("SessionRestore"));
+    settings.setValue(QSL("isRunning"), false);
+    settings.setValue(QSL("isRestoring"), false);
     settings.endGroup();
 
-    settings.beginGroup("Web-Browser-Settings");
-    bool deleteCache = settings.value("deleteCacheOnClose", false).toBool();
-    bool deleteHistory = settings.value("deleteHistoryOnClose", false).toBool();
-    bool deleteHtml5Storage = settings.value("deleteHTML5StorageOnClose", false).toBool();
+    settings.beginGroup(QSL("Web-Browser-Settings"));
+    bool deleteCache = settings.value(QSL("deleteCacheOnClose"), false).toBool();
+    bool deleteHistory = settings.value(QSL("deleteHistoryOnClose"), false).toBool();
+    bool deleteHtml5Storage = settings.value(QSL("deleteHTML5StorageOnClose"), false).toBool();
     settings.endGroup();
 
-    settings.beginGroup("Cookie-Settings");
-    bool deleteCookies = settings.value("deleteCookiesOnClose", false).toBool();
+    settings.beginGroup(QSL("Cookie-Settings"));
+    bool deleteCookies = settings.value(QSL("deleteCookiesOnClose"), false).toBool();
     settings.endGroup();
 
     if (deleteHistory) {
@@ -784,7 +806,7 @@ void MainApplication::saveSettings()
         ClearPrivateData::clearLocalStorage();
     }
     if (deleteCookies) {
-        m_cookieJar->deleteAllCookies();
+        m_cookieJar->deleteAllCookies(false);
     }
     if (deleteCache) {
         QzTools::removeRecursively(mApp->webProfile()->cachePath());
@@ -893,8 +915,8 @@ void MainApplication::downloadRequested(QWebEngineDownloadItem *download)
 void MainApplication::loadSettings()
 {
     Settings settings;
-    settings.beginGroup("Themes");
-    QString activeTheme = settings.value("activeTheme", DEFAULT_THEME_NAME).toString();
+    settings.beginGroup(QSL("Themes"));
+    QString activeTheme = settings.value(QSL("activeTheme"), DEFAULT_THEME_NAME).toString();
     settings.endGroup();
 
     loadTheme(activeTheme);
@@ -902,43 +924,58 @@ void MainApplication::loadSettings()
     QWebEngineSettings* webSettings = m_webProfile->settings();
 
     // Web browsing settings
-    settings.beginGroup("Web-Browser-Settings");
+    settings.beginGroup(QSL("Web-Browser-Settings"));
 
-    webSettings->setAttribute(QWebEngineSettings::LocalStorageEnabled, settings.value("HTML5StorageEnabled", true).toBool());
-    webSettings->setAttribute(QWebEngineSettings::PluginsEnabled, settings.value("allowPlugins", true).toBool());
-    webSettings->setAttribute(QWebEngineSettings::JavascriptEnabled, settings.value("allowJavaScript", true).toBool());
-    webSettings->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, settings.value("allowJavaScriptOpenWindow", false).toBool());
-    webSettings->setAttribute(QWebEngineSettings::JavascriptCanAccessClipboard, settings.value("allowJavaScriptAccessClipboard", true).toBool());
-    webSettings->setAttribute(QWebEngineSettings::LinksIncludedInFocusChain, settings.value("IncludeLinkInFocusChain", false).toBool());
-    webSettings->setAttribute(QWebEngineSettings::XSSAuditingEnabled, settings.value("XSSAuditing", false).toBool());
-    webSettings->setAttribute(QWebEngineSettings::PrintElementBackgrounds, settings.value("PrintElementBackground", true).toBool());
-    webSettings->setAttribute(QWebEngineSettings::SpatialNavigationEnabled, settings.value("SpatialNavigation", false).toBool());
-    webSettings->setAttribute(QWebEngineSettings::ScrollAnimatorEnabled, settings.value("AnimateScrolling", true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::LocalStorageEnabled, settings.value(QSL("HTML5StorageEnabled"), true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::PluginsEnabled, settings.value(QSL("allowPlugins"), true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::JavascriptEnabled, settings.value(QSL("allowJavaScript"), true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, settings.value(QSL("allowJavaScriptOpenWindow"), false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::JavascriptCanAccessClipboard, settings.value(QSL("allowJavaScriptAccessClipboard"), true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::LinksIncludedInFocusChain, settings.value(QSL("IncludeLinkInFocusChain"), false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::XSSAuditingEnabled, settings.value(QSL("XSSAuditing"), false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::PrintElementBackgrounds, settings.value(QSL("PrintElementBackground"), true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::SpatialNavigationEnabled, settings.value(QSL("SpatialNavigation"), false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::ScrollAnimatorEnabled, settings.value(QSL("AnimateScrolling"), true).toBool());
     webSettings->setAttribute(QWebEngineSettings::HyperlinkAuditingEnabled, false);
     webSettings->setAttribute(QWebEngineSettings::FullScreenSupportEnabled, true);
     webSettings->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, true);
     webSettings->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
 
-    webSettings->setDefaultTextEncoding(settings.value("DefaultEncoding", webSettings->defaultTextEncoding()).toString());
+#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    webSettings->setAttribute(QWebEngineSettings::AllowWindowActivationFromJavaScript, settings.value(QSL("allowJavaScriptActivateWindow"), false).toBool());
+#endif
 
-    setWheelScrollLines(settings.value("wheelScrollLines", wheelScrollLines()).toInt());
+#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    webSettings->setAttribute(QWebEngineSettings::JavascriptCanPaste, settings.value(QSL("allowJavaScriptPaste"), true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::PlaybackRequiresUserGesture, settings.value(QSL("DisableVideoAutoPlay"), false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::WebRTCPublicInterfacesOnly, settings.value(QSL("WebRTCPublicIpOnly"), true).toBool());
+    webSettings->setUnknownUrlSchemePolicy(QWebEngineSettings::AllowAllUnknownUrlSchemes);
+#endif
 
-    const QString userCss = settings.value("userStyleSheet", QString()).toString();
+#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 12, 0)
+    webSettings->setAttribute(QWebEngineSettings::DnsPrefetchEnabled, settings.value(QSL("DNSPrefetch"), true).toBool());
+#endif
+
+    webSettings->setDefaultTextEncoding(settings.value(QSL("DefaultEncoding"), webSettings->defaultTextEncoding()).toString());
+
+    setWheelScrollLines(settings.value(QSL("wheelScrollLines"), wheelScrollLines()).toInt());
+
+    const QString userCss = settings.value(QSL("userStyleSheet"), QString()).toString();
     settings.endGroup();
 
     setUserStyleSheet(userCss);
 
-    settings.beginGroup("Browser-Fonts");
-    webSettings->setFontFamily(QWebEngineSettings::StandardFont, settings.value("StandardFont", webSettings->fontFamily(QWebEngineSettings::StandardFont)).toString());
-    webSettings->setFontFamily(QWebEngineSettings::CursiveFont, settings.value("CursiveFont", webSettings->fontFamily(QWebEngineSettings::CursiveFont)).toString());
-    webSettings->setFontFamily(QWebEngineSettings::FantasyFont, settings.value("FantasyFont", webSettings->fontFamily(QWebEngineSettings::FantasyFont)).toString());
-    webSettings->setFontFamily(QWebEngineSettings::FixedFont, settings.value("FixedFont", webSettings->fontFamily(QWebEngineSettings::FixedFont)).toString());
-    webSettings->setFontFamily(QWebEngineSettings::SansSerifFont, settings.value("SansSerifFont", webSettings->fontFamily(QWebEngineSettings::SansSerifFont)).toString());
-    webSettings->setFontFamily(QWebEngineSettings::SerifFont, settings.value("SerifFont", webSettings->fontFamily(QWebEngineSettings::SerifFont)).toString());
-    webSettings->setFontSize(QWebEngineSettings::DefaultFontSize, settings.value("DefaultFontSize", 15).toInt());
-    webSettings->setFontSize(QWebEngineSettings::DefaultFixedFontSize, settings.value("FixedFontSize", 14).toInt());
-    webSettings->setFontSize(QWebEngineSettings::MinimumFontSize, settings.value("MinimumFontSize", 3).toInt());
-    webSettings->setFontSize(QWebEngineSettings::MinimumLogicalFontSize, settings.value("MinimumLogicalFontSize", 5).toInt());
+    settings.beginGroup(QSL("Browser-Fonts"));
+    webSettings->setFontFamily(QWebEngineSettings::StandardFont, settings.value(QSL("StandardFont"), webSettings->fontFamily(QWebEngineSettings::StandardFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::CursiveFont, settings.value(QSL("CursiveFont"), webSettings->fontFamily(QWebEngineSettings::CursiveFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::FantasyFont, settings.value(QSL("FantasyFont"), webSettings->fontFamily(QWebEngineSettings::FantasyFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::FixedFont, settings.value(QSL("FixedFont"), webSettings->fontFamily(QWebEngineSettings::FixedFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::SansSerifFont, settings.value(QSL("SansSerifFont"), webSettings->fontFamily(QWebEngineSettings::SansSerifFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::SerifFont, settings.value(QSL("SerifFont"), webSettings->fontFamily(QWebEngineSettings::SerifFont)).toString());
+    webSettings->setFontSize(QWebEngineSettings::DefaultFontSize, settings.value(QSL("DefaultFontSize"), 15).toInt());
+    webSettings->setFontSize(QWebEngineSettings::DefaultFixedFontSize, settings.value(QSL("FixedFontSize"), 14).toInt());
+    webSettings->setFontSize(QWebEngineSettings::MinimumFontSize, settings.value(QSL("MinimumFontSize"), 3).toInt());
+    webSettings->setFontSize(QWebEngineSettings::MinimumLogicalFontSize, settings.value(QSL("MinimumLogicalFontSize"), 5).toInt());
     settings.endGroup();
 
     QWebEngineProfile* profile = QWebEngineProfile::defaultProfile();
@@ -948,7 +985,7 @@ void MainApplication::loadSettings()
     QString defaultPath = DataPaths::path(DataPaths::Cache);
     if (!defaultPath.startsWith(DataPaths::currentProfilePath()))
         defaultPath.append(QLatin1Char('/') + ProfileManager::currentProfile());
-    const QString &cachePath = settings.value("Web-Browser-Settings/CachePath", defaultPath).toString();
+    const QString &cachePath = settings.value(QSL("Web-Browser-Settings/CachePath"), defaultPath).toString();
     profile->setCachePath(cachePath);
 
     const bool allowCache = settings.value(QSL("Web-Browser-Settings/AllowLocalCache"), true).toBool();
@@ -982,7 +1019,7 @@ void MainApplication::loadTheme(const QString &name)
 
     if (activeThemePath.isEmpty()) {
         qWarning() << "Cannot load theme " << name;
-        activeThemePath = QString("%1/%2").arg(DataPaths::path(DataPaths::Themes), DEFAULT_THEME_NAME);
+        activeThemePath = QSL("%1/%2").arg(DataPaths::path(DataPaths::Themes), DEFAULT_THEME_NAME);
     }
 
     QString qss = QzTools::readAllFileContents(activeThemePath + QLatin1String("/main.css"));
@@ -1006,7 +1043,7 @@ void MainApplication::loadTheme(const QString &name)
     qss.append(QzTools::readAllFileContents(DataPaths::currentProfilePath() + QL1S("/userChrome.css")));
 
     QString relativePath = QDir::current().relativeFilePath(activeThemePath);
-    qss.replace(QRegularExpression(QSL("url\\s*\\(\\s*([^\\*:\\);]+)\\s*\\)")), QString("url(%1/\\1)").arg(relativePath));
+    qss.replace(QRegularExpression(QSL("url\\s*\\(\\s*([^\\*:\\);]+)\\s*\\)")), QSL("url(%1/\\1)").arg(relativePath));
     setStyleSheet(qss);
 }
 
@@ -1018,7 +1055,7 @@ void MainApplication::checkDefaultWebBrowser()
 
 #if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
     Settings settings;
-    bool checkNow = settings.value("Web-Browser-Settings/CheckDefaultBrowser", DEFAULT_CHECK_DEFAULTBROWSER).toBool();
+    bool checkNow = settings.value(QSL("Web-Browser-Settings/CheckDefaultBrowser"), DEFAULT_CHECK_DEFAULTBROWSER).toBool();
 
     if (!checkNow) {
         return;
@@ -1043,7 +1080,7 @@ void MainApplication::checkDefaultWebBrowser()
         checkAgain = dialog.isChecked();
     }
 
-    settings.setValue("Web-Browser-Settings/CheckDefaultBrowser", checkAgain);
+    settings.setValue(QSL("Web-Browser-Settings/CheckDefaultBrowser"), checkAgain);
 #endif
 }
 
