@@ -28,13 +28,13 @@ class FALKON_EXPORT ChromeImporter : public BookmarksImporter
 public:
     explicit ChromeImporter(QObject* parent = 0);
 
-    QString description() const;
-    QString standardPath() const;
+    QString description() const override;
+    QString standardPath() const override;
 
-    QString getPath(QWidget* parent);
-    bool prepareImport();
+    QString getPath(QWidget* parent) override;
+    bool prepareImport() override;
 
-    BookmarkItem* importBookmarks();
+    BookmarkItem* importBookmarks() override;
 
 private:
     void readBookmarks(const QVariantList &list, BookmarkItem* parent);
