@@ -18,10 +18,12 @@
 #include "bookmarkstoolbar.h"
 #include "bookmarkstoolbarbutton.h"
 #include "bookmarkstools.h"
+#include "bookmarksmodel.h"
 #include "bookmarkitem.h"
 #include "bookmarks.h"
 #include "mainapplication.h"
 #include "iconprovider.h"
+#include "qztools.h"
 
 #include <QDragEnterEvent>
 #include <QHBoxLayout>
@@ -34,6 +36,7 @@ BookmarksToolbar::BookmarksToolbar(BrowserWindow* window, QWidget* parent)
     , m_window(window)
     , m_bookmarks(mApp->bookmarks())
     , m_clickedBookmark(0)
+    , m_dropRow(-1)
 {
     setObjectName("bookmarksbar");
     setAcceptDrops(true);
@@ -48,14 +51,14 @@ BookmarksToolbar::BookmarksToolbar(BrowserWindow* window, QWidget* parent)
     m_updateTimer = new QTimer(this);
     m_updateTimer->setInterval(300);
     m_updateTimer->setSingleShot(true);
-    connect(m_updateTimer, SIGNAL(timeout()), this, SLOT(refresh()));
+    connect(m_updateTimer, &QTimer::timeout, this, &BookmarksToolbar::refresh);
 
-    connect(m_bookmarks, SIGNAL(bookmarkAdded(BookmarkItem*)), this, SLOT(bookmarksChanged()));
-    connect(m_bookmarks, SIGNAL(bookmarkRemoved(BookmarkItem*)), this, SLOT(bookmarksChanged()));
-    connect(m_bookmarks, SIGNAL(bookmarkChanged(BookmarkItem*)), this, SLOT(bookmarksChanged()));
-    connect(m_bookmarks, SIGNAL(showOnlyIconsInToolbarChanged(bool)), this, SLOT(showOnlyIconsChanged(bool)));
-    connect(m_bookmarks, SIGNAL(showOnlyTextInToolbarChanged(bool)), this, SLOT(showOnlyTextChanged(bool)));
-    connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenuRequested(QPoint)));
+    connect(m_bookmarks, &Bookmarks::bookmarkAdded, this, &BookmarksToolbar::bookmarksChanged);
+    connect(m_bookmarks, &Bookmarks::bookmarkRemoved, this, &BookmarksToolbar::bookmarksChanged);
+    connect(m_bookmarks, &Bookmarks::bookmarkChanged, this, &BookmarksToolbar::bookmarksChanged);
+    connect(m_bookmarks, &Bookmarks::showOnlyIconsInToolbarChanged, this, &BookmarksToolbar::showOnlyIconsChanged);
+    connect(m_bookmarks, &Bookmarks::showOnlyTextInToolbarChanged, this, &BookmarksToolbar::showOnlyTextChanged);
+    connect(this, &QWidget::customContextMenuRequested, this, &BookmarksToolbar::contextMenuRequested);
 
     refresh();
 }
@@ -76,17 +79,17 @@ void BookmarksToolbar::contextMenuRequested(const QPoint &pos)
     m_actShowOnlyIcons = menu.addAction(tr("Show Only Icons"));
     m_actShowOnlyIcons->setCheckable(true);
     m_actShowOnlyIcons->setChecked(m_bookmarks->showOnlyIconsInToolbar());
-    connect(m_actShowOnlyIcons, SIGNAL(toggled(bool)), m_bookmarks, SLOT(setShowOnlyIconsInToolbar(bool)));
+    connect(m_actShowOnlyIcons, &QAction::toggled, m_bookmarks, &Bookmarks::setShowOnlyIconsInToolbar);
     m_actShowOnlyText = menu.addAction(tr("Show Only Text"));
     m_actShowOnlyText->setCheckable(true);
     m_actShowOnlyText->setChecked(m_bookmarks->showOnlyTextInToolbar());
-    connect(m_actShowOnlyText, SIGNAL(toggled(bool)), m_bookmarks, SLOT(setShowOnlyTextInToolbar(bool)));
+    connect(m_actShowOnlyText, &QAction::toggled, m_bookmarks, &Bookmarks::setShowOnlyTextInToolbar);
 
-    connect(actNewTab, SIGNAL(triggered()), this, SLOT(openBookmarkInNewTab()));
-    connect(actNewWindow, SIGNAL(triggered()), this, SLOT(openBookmarkInNewWindow()));
-    connect(actNewPrivateWindow, SIGNAL(triggered()), this, SLOT(openBookmarkInNewPrivateWindow()));
-    connect(actEdit, SIGNAL(triggered()), this, SLOT(editBookmark()));
-    connect(actDelete, SIGNAL(triggered()), this, SLOT(deleteBookmark()));
+    connect(actNewTab, &QAction::triggered, this, &BookmarksToolbar::openBookmarkInNewTab);
+    connect(actNewWindow, &QAction::triggered, this, &BookmarksToolbar::openBookmarkInNewWindow);
+    connect(actNewPrivateWindow, &QAction::triggered, this, &BookmarksToolbar::openBookmarkInNewPrivateWindow);
+    connect(actEdit, &QAction::triggered, this, &BookmarksToolbar::editBookmark);
+    connect(actDelete, &QAction::triggered, this, &BookmarksToolbar::deleteBookmark);
 
     actEdit->setEnabled(m_clickedBookmark && m_bookmarks->canBeModified(m_clickedBookmark));
     actDelete->setEnabled(m_clickedBookmark && m_bookmarks->canBeModified(m_clickedBookmark));
@@ -226,36 +229,104 @@ QSize BookmarksToolbar::minimumSizeHint() const
 
 void BookmarksToolbar::dropEvent(QDropEvent* e)
 {
+    int row = m_dropRow;
+    clearDropIndicator();
+
     const QMimeData* mime = e->mimeData();
 
-    if (!mime->hasUrls()) {
+    if (!mime->hasUrls() && !mime->hasFormat(BookmarksButtonMimeData::mimeType())) {
         QWidget::dropEvent(e);
         return;
     }
 
-    QUrl url = mime->urls().at(0);
-    QString title = mime->hasText() ? mime->text() : url.toEncoded(QUrl::RemoveScheme);
-
     BookmarkItem* parent = m_bookmarks->toolbarFolder();
-    BookmarksToolbarButton* button = buttonAt(e->pos());
-    if (button && button->bookmark()->isFolder()) {
-        parent = button->bookmark();
+    BookmarkItem* bookmark = nullptr;
+
+    if (mime->hasFormat(BookmarksButtonMimeData::mimeType())) {
+        const BookmarksButtonMimeData* bookmarkMime = static_cast<const BookmarksButtonMimeData*>(mime);
+        bookmark = bookmarkMime->item();
+        const int initialIndex = bookmark->parent()->children().indexOf(bookmark);
+        BookmarksToolbarButton* current = buttonAt(m_dropPos);
+        if (initialIndex < m_layout->indexOf(current)) {
+            row -= 1;
+        }
+    } else {
+        const QUrl url = mime->urls().at(0);
+        const QString title = mime->hasText() ? mime->text() : url.toEncoded(QUrl::RemoveScheme);
+
+        bookmark = new BookmarkItem(BookmarkItem::Url);
+        bookmark->setTitle(title);
+        bookmark->setUrl(url);
     }
 
-    BookmarkItem* bookmark = new BookmarkItem(BookmarkItem::Url);
-    bookmark->setTitle(title);
-    bookmark->setUrl(url);
-    m_bookmarks->addBookmark(parent, bookmark);
+    if (row >= 0) {
+        m_bookmarks->insertBookmark(parent, row, bookmark);
+    } else {
+        m_bookmarks->addBookmark(parent, bookmark);
+    }
 }
 
 void BookmarksToolbar::dragEnterEvent(QDragEnterEvent* e)
 {
     const QMimeData* mime = e->mimeData();
 
-    if (mime->hasUrls() && mime->hasText()) {
+    if ((mime->hasUrls() && mime->hasText()) || mime->hasFormat(BookmarksButtonMimeData::mimeType())) {
         e->acceptProposedAction();
         return;
     }
 
     QWidget::dragEnterEvent(e);
 }
+
+void BookmarksToolbar::dragMoveEvent(QDragMoveEvent *e)
+{
+    int eventX = e->pos().x();
+    BookmarksToolbarButton* button = buttonAt(e->pos());
+    m_dropPos = e->pos();
+    m_dropRow = m_layout->indexOf(button);
+    if (button) {
+        bool res = eventX - button->x() < button->x() + button->width() -eventX;
+        m_dropRow = res ? m_dropRow : m_dropRow + 1;
+    } else {
+        m_dropRow = -1;
+    }
+
+    update();
+}
+
+void BookmarksToolbar::dragLeaveEvent(QDragLeaveEvent *e)
+{
+    Q_UNUSED(e);
+    clearDropIndicator();
+}
+
+void BookmarksToolbar::clearDropIndicator()
+{
+    m_dropRow = -1;
+    update();
+}
+
+void BookmarksToolbar::paintEvent(QPaintEvent *p)
+{
+    QWidget::paintEvent(p);
+
+    // Draw drop indicator
+    if (m_dropRow != -1) {
+        BookmarksToolbarButton* button = buttonAt(m_dropPos);
+        if (button) {
+            if (button->bookmark()->isFolder()) {
+                return;
+            }
+            const QRect tr = QRect(button->x(), 0, button->width(), height());
+            QRect r;
+
+            if (m_dropRow == m_layout->indexOf(button)) {
+                r = QRect(qMax(0, tr.left() - 2), tr.top(), 3, tr.height());
+            } else {
+                r = QRect(tr.right() + 0, tr.top(), 3, tr.height());
+            }
+
+            QzTools::paintDropIndicator(this, r);
+        }
+    }
+}
