@@ -27,8 +27,8 @@ class FALKON_EXPORT LocationCompleterDelegate : public QStyledItemDelegate
 public:
     explicit LocationCompleterDelegate(QObject *parent = 0);
 
-    void paint(QPainter* painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    void paint(QPainter* painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     void setForceVisitItem(bool enable);
 
