@@ -27,8 +27,8 @@ public:
     explicit GoIcon(QWidget* parent = 0);
 
 private:
-    void contextMenuEvent(QContextMenuEvent* ev);
-    void mousePressEvent(QMouseEvent* ev);
+    void contextMenuEvent(QContextMenuEvent* ev) override;
+    void mousePressEvent(QMouseEvent* ev) override;
 
 };
 
