@@ -46,6 +46,7 @@
 #include "html5permissions/html5permissionsdialog.h"
 #include "searchenginesdialog.h"
 #include "webscrollbarmanager.h"
+#include "protocolhandlerdialog.h"
 #include "../config.h"
 
 #include <QSettings>
@@ -58,6 +59,7 @@
 #include <QWebEngineProfile>
 #include <QWebEngineSettings>
 #include <QLibraryInfo>
+#include <QtWebEngineWidgetsVersion>
 
 static QString createLanguageItem(const QString &lang)
 {
@@ -110,6 +112,15 @@ Preferences::Preferences(BrowserWindow* window)
     ui->checkUpdates->setVisible(false);
 #endif
 
+#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 11, 0)
+    ui->disableVideoAutoPlay->setVisible(false);
+    ui->webRTCPublicIpOnly->setVisible(false);
+#endif
+
+#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 12, 0)
+    ui->dnsPrefetch->setVisible(false);
+#endif
+
     auto setCategoryIcon = [this](int index, const QIcon &icon) {
         ui->listWidget->item(index)->setIcon(QIcon(icon.pixmap(32)));
     };
@@ -185,8 +196,8 @@ Preferences::Preferences(BrowserWindow* window)
     connect(ui->afterLaunch, SIGNAL(currentIndexChanged(int)), this, SLOT(afterLaunchChanged(int)));
     connect(ui->newTab, SIGNAL(currentIndexChanged(int)), this, SLOT(newTabChanged(int)));
     if (m_window) {
-        connect(ui->useCurrentBut, SIGNAL(clicked()), this, SLOT(useActualHomepage()));
-        connect(ui->newTabUseCurrent, SIGNAL(clicked()), this, SLOT(useActualNewTab()));
+        connect(ui->useCurrentBut, &QAbstractButton::clicked, this, &Preferences::useActualHomepage);
+        connect(ui->newTabUseCurrent, &QAbstractButton::clicked, this, &Preferences::useActualNewTab);
     }
     else {
         ui->useCurrentBut->setEnabled(false);
@@ -204,8 +215,8 @@ Preferences::Preferences(BrowserWindow* window)
         }
     }
 
-    connect(ui->createProfile, SIGNAL(clicked()), this, SLOT(createProfile()));
-    connect(ui->deleteProfile, SIGNAL(clicked()), this, SLOT(deleteProfile()));
+    connect(ui->createProfile, &QAbstractButton::clicked, this, &Preferences::createProfile);
+    connect(ui->deleteProfile, &QAbstractButton::clicked, this, &Preferences::deleteProfile);
     connect(ui->startProfile, SIGNAL(currentIndexChanged(int)), this, SLOT(startProfileIndexChanged(int)));
     startProfileIndexChanged(ui->startProfile->currentIndex());
 
@@ -217,8 +228,8 @@ Preferences::Preferences(BrowserWindow* window)
     ui->showBookmarksToolbar->setChecked(settings.value("showBookmarksToolbar", false).toBool());
     ui->instantBookmarksToolbar->setDisabled(settings.value("showBookmarksToolbar", false).toBool());
     ui->showBookmarksToolbar->setDisabled(settings.value("instantBookmarksToolbar").toBool());
-    connect(ui->instantBookmarksToolbar, SIGNAL(toggled(bool)), ui->showBookmarksToolbar, SLOT(setDisabled(bool)));
-    connect(ui->showBookmarksToolbar, SIGNAL(toggled(bool)), ui->instantBookmarksToolbar, SLOT(setDisabled(bool)));
+    connect(ui->instantBookmarksToolbar, &QAbstractButton::toggled, ui->showBookmarksToolbar, &QWidget::setDisabled);
+    connect(ui->showBookmarksToolbar, &QAbstractButton::toggled, ui->instantBookmarksToolbar, &QWidget::setDisabled);
     ui->showNavigationToolbar->setChecked(settings.value("showNavigationToolbar", true).toBool());
     int currentSettingsPage = settings.value("settingsDialogPage", 0).toInt(0);
     settings.endGroup();
@@ -255,7 +266,7 @@ Preferences::Preferences(BrowserWindow* window)
     ui->progressBarColorSelector->setEnabled(pbInABuseCC);
     QColor pbColor = settings.value("CustomProgressColor", palette().color(QPalette::Highlight)).value<QColor>();
     setProgressBarColorIcon(pbColor);
-    connect(ui->customColorToolButton, SIGNAL(clicked(bool)), SLOT(selectCustomProgressBarColor()));
+    connect(ui->customColorToolButton, &QAbstractButton::clicked, this, &Preferences::selectCustomProgressBarColor);
     connect(ui->resetProgressBarcolor, SIGNAL(clicked()), SLOT(setProgressBarColorIcon()));
     settings.endGroup();
 
@@ -266,7 +277,7 @@ Preferences::Preferences(BrowserWindow* window)
     ui->searchWithDefaultEngine->setChecked(settings.value("SearchWithDefaultEngine", false).toBool());
     ui->showABSearchSuggestions->setEnabled(searchFromAB);
     ui->showABSearchSuggestions->setChecked(settings.value("showSearchSuggestions", true).toBool());
-    connect(ui->searchFromAddressBar, SIGNAL(toggled(bool)), this, SLOT(searchFromAddressBarChanged(bool)));
+    connect(ui->searchFromAddressBar, &QAbstractButton::toggled, this, &Preferences::searchFromAddressBarChanged);
     settings.endGroup();
 
     // BROWSING
@@ -280,6 +291,9 @@ Preferences::Preferences(BrowserWindow* window)
     ui->xssAuditing->setChecked(settings.value("XSSAuditing", false).toBool());
     ui->printEBackground->setChecked(settings.value("PrintElementBackground", true).toBool());
     ui->useNativeScrollbars->setChecked(settings.value("UseNativeScrollbars", false).toBool());
+    ui->disableVideoAutoPlay->setChecked(settings.value("DisableVideoAutoPlay", false).toBool());
+    ui->webRTCPublicIpOnly->setChecked(settings.value("WebRTCPublicIpOnly", true).toBool());
+    ui->dnsPrefetch->setChecked(settings.value("DNSPrefetch", true).toBool());
 
     foreach (int level, WebView::zoomLevels()) {
         ui->defaultZoomLevel->addItem(QString("%1%").arg(level));
@@ -292,8 +306,8 @@ Preferences::Preferences(BrowserWindow* window)
     ui->removeCache->setChecked(settings.value("deleteCacheOnClose", false).toBool());
     ui->cacheMB->setValue(settings.value("LocalCacheSize", 50).toInt());
     ui->cachePath->setText(settings.value("CachePath", QWebEngineProfile::defaultProfile()->cachePath()).toString());
-    connect(ui->allowCache, SIGNAL(clicked(bool)), this, SLOT(allowCacheChanged(bool)));
-    connect(ui->changeCachePath, SIGNAL(clicked()), this, SLOT(changeCachePathClicked()));
+    connect(ui->allowCache, &QAbstractButton::clicked, this, &Preferences::allowCacheChanged);
+    connect(ui->changeCachePath, &QAbstractButton::clicked, this, &Preferences::changeCachePathClicked);
     allowCacheChanged(ui->allowCache->isChecked());
 
     //PASSWORD MANAGER
@@ -307,18 +321,18 @@ Preferences::Preferences(BrowserWindow* window)
     if (!ui->saveHistory->isChecked()) {
         ui->deleteHistoryOnClose->setEnabled(false);
     }
-    connect(ui->saveHistory, SIGNAL(toggled(bool)), this, SLOT(saveHistoryChanged(bool)));
+    connect(ui->saveHistory, &QAbstractButton::toggled, this, &Preferences::saveHistoryChanged);
 
     // Html5Storage
     ui->html5storage->setChecked(settings.value("HTML5StorageEnabled", true).toBool());
     ui->deleteHtml5storageOnClose->setChecked(settings.value("deleteHTML5StorageOnClose", false).toBool());
-    connect(ui->html5storage, SIGNAL(toggled(bool)), this, SLOT(allowHtml5storageChanged(bool)));
+    connect(ui->html5storage, &QAbstractButton::toggled, this, &Preferences::allowHtml5storageChanged);
     // Other
     ui->doNotTrack->setChecked(settings.value("DoNotTrack", false).toBool());
 
     //CSS Style
     ui->userStyleSheet->setText(settings.value("userStyleSheet", "").toString());
-    connect(ui->chooseUserStylesheet, SIGNAL(clicked()), this, SLOT(chooseUserStyleClicked()));
+    connect(ui->chooseUserStylesheet, &QAbstractButton::clicked, this, &Preferences::chooseUserStyleClicked);
     settings.endGroup();
 
     //DOWNLOADS
@@ -335,12 +349,12 @@ Preferences::Preferences(BrowserWindow* window)
     ui->externalDownExecutable->setText(settings.value("ExternalManagerExecutable", "").toString());
     ui->externalDownArguments->setText(settings.value("ExternalManagerArguments", "").toString());
 
-    connect(ui->useExternalDownManager, SIGNAL(toggled(bool)), this, SLOT(useExternalDownManagerChanged(bool)));
+    connect(ui->useExternalDownManager, &QAbstractButton::toggled, this, &Preferences::useExternalDownManagerChanged);
 
 
-    connect(ui->useDefined, SIGNAL(toggled(bool)), this, SLOT(downLocChanged(bool)));
-    connect(ui->downButt, SIGNAL(clicked()), this, SLOT(chooseDownPath()));
-    connect(ui->chooseExternalDown, SIGNAL(clicked()), this, SLOT(chooseExternalDownloadManager()));
+    connect(ui->useDefined, &QAbstractButton::toggled, this, &Preferences::downLocChanged);
+    connect(ui->downButt, &QAbstractButton::clicked, this, &Preferences::chooseDownPath);
+    connect(ui->chooseExternalDown, &QAbstractButton::clicked, this, &Preferences::chooseExternalDownloadManager);
     downLocChanged(ui->useDefined->isChecked());
     useExternalDownManagerChanged(ui->useExternalDownManager->isChecked());
     settings.endGroup();
@@ -488,19 +502,20 @@ Preferences::Preferences(BrowserWindow* window)
     settings.endGroup();
 
     setManualProxyConfigurationEnabled(ui->manualProxy->isChecked());
-    connect(ui->manualProxy, SIGNAL(toggled(bool)), this, SLOT(setManualProxyConfigurationEnabled(bool)));
+    connect(ui->manualProxy, &QAbstractButton::toggled, this, &Preferences::setManualProxyConfigurationEnabled);
 
     //CONNECTS
-    connect(ui->buttonBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(buttonClicked(QAbstractButton*)));
-    connect(ui->cookieManagerBut, SIGNAL(clicked()), this, SLOT(showCookieManager()));
-    connect(ui->html5permissions, SIGNAL(clicked()), this, SLOT(showHtml5Permissions()));
-    connect(ui->preferredLanguages, SIGNAL(clicked()), this, SLOT(showAcceptLanguage()));
-    connect(ui->deleteHtml5storage, SIGNAL(clicked()), this, SLOT(deleteHtml5storage()));
-    connect(ui->uaManager, SIGNAL(clicked()), this, SLOT(openUserAgentManager()));
-    connect(ui->jsOptionsButton, SIGNAL(clicked()), this, SLOT(openJsOptions()));
-    connect(ui->searchEngines, SIGNAL(clicked()), this, SLOT(openSearchEnginesManager()));
+    connect(ui->buttonBox, &QDialogButtonBox::clicked, this, &Preferences::buttonClicked);
+    connect(ui->cookieManagerBut, &QAbstractButton::clicked, this, &Preferences::showCookieManager);
+    connect(ui->html5permissions, &QAbstractButton::clicked, this, &Preferences::showHtml5Permissions);
+    connect(ui->preferredLanguages, &QAbstractButton::clicked, this, &Preferences::showAcceptLanguage);
+    connect(ui->deleteHtml5storage, &QAbstractButton::clicked, this, &Preferences::deleteHtml5storage);
+    connect(ui->uaManager, &QAbstractButton::clicked, this, &Preferences::openUserAgentManager);
+    connect(ui->jsOptionsButton, &QAbstractButton::clicked, this, &Preferences::openJsOptions);
+    connect(ui->searchEngines, &QAbstractButton::clicked, this, &Preferences::openSearchEnginesManager);
+    connect(ui->protocolHandlers, &QAbstractButton::clicked, this, &Preferences::openProtocolHandlersManager);
 
-    connect(ui->listWidget, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), this, SLOT(showStackedPage(QListWidgetItem*)));
+    connect(ui->listWidget, &QListWidget::currentItemChanged, this, &Preferences::showStackedPage);
     ui->listWidget->setItemSelected(ui->listWidget->itemAt(5, 5), true);
 
     ui->listWidget->setCurrentRow(currentSettingsPage);
@@ -714,6 +729,12 @@ void Preferences::openSearchEnginesManager()
     dialog->open();
 }
 
+void Preferences::openProtocolHandlersManager()
+{
+    ProtocolHandlerDialog *dialog = new ProtocolHandlerDialog(this);
+    dialog->open();
+}
+
 void Preferences::showAcceptLanguage()
 {
     AcceptLanguage* dialog = new AcceptLanguage(this);
@@ -933,6 +954,10 @@ void Preferences::saveSettings()
     settings.setValue("PrintElementBackground", ui->printEBackground->isChecked());
     settings.setValue("closeAppWithCtrlQ", ui->closeAppWithCtrlQ->isChecked());
     settings.setValue("UseNativeScrollbars", ui->useNativeScrollbars->isChecked());
+    settings.setValue("DisableVideoAutoPlay", ui->disableVideoAutoPlay->isChecked());
+    settings.setValue("WebRTCPublicIpOnly", ui->webRTCPublicIpOnly->isChecked());
+    settings.setValue("DNSPrefetch", ui->dnsPrefetch->isChecked());
+
 #ifdef Q_OS_WIN
     settings.setValue("CheckDefaultBrowser", ui->checkDefaultBrowser->isChecked());
 #endif
