@@ -65,8 +65,8 @@ ThemeManager::ThemeManager(QWidget* parent, Preferences* preferences)
         }
     }
 
-    connect(ui->listWidget, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), this, SLOT(currentChanged()));
-    connect(ui->license, SIGNAL(clicked(QPoint)), this, SLOT(showLicense()));
+    connect(ui->listWidget, &QListWidget::currentItemChanged, this, &ThemeManager::currentChanged);
+    connect(ui->license, &ClickableLabel::clicked, this, &ThemeManager::showLicense);
 
     currentChanged();
 }
@@ -96,7 +96,7 @@ void ThemeManager::currentChanged()
 
     ui->name->setText(currentTheme.name);
     ui->author->setText(currentTheme.author);
-    ui->descirption->setText(currentTheme.description);
+    ui->description->setText(currentTheme.description);
     ui->license->setHidden(currentTheme.license.isEmpty());
 }
 
