@@ -35,23 +35,20 @@ SearchToolBar::SearchToolBar(WebView* view, QWidget* parent)
     ui->setupUi(this);
 
     ui->closeButton->setIcon(IconProvider::instance()->standardIcon(QStyle::SP_DialogCloseButton));
-    ui->next->setIcon(IconProvider::instance()->standardIcon(QStyle::SP_ArrowDown));
     ui->next->setShortcut(QKeySequence("Ctrl+G"));
-    ui->previous->setIcon(IconProvider::instance()->standardIcon(QStyle::SP_ArrowUp));
     ui->previous->setShortcut(QKeySequence("Ctrl+Shift+G"));
 
     connect(ui->closeButton, SIGNAL(clicked()), this, SLOT(close()));
-    connect(ui->lineEdit, SIGNAL(textChanged(QString)), this, SLOT(findNext()));
-    connect(ui->lineEdit, SIGNAL(returnPressed()), this, SLOT(findNext()));
-    connect(ui->next, SIGNAL(clicked()), this, SLOT(findNext()));
-    connect(ui->previous, SIGNAL(clicked()), this, SLOT(findPrevious()));
-    connect(ui->caseSensitive, SIGNAL(clicked()), this, SLOT(caseSensitivityChanged()));
+    connect(ui->lineEdit, &QLineEdit::textEdited, this, &SearchToolBar::findNext);
+    connect(ui->next, &QAbstractButton::clicked, this, &SearchToolBar::findNext);
+    connect(ui->previous, &QAbstractButton::clicked, this, &SearchToolBar::findPrevious);
+    connect(ui->caseSensitive, &QAbstractButton::clicked, this, &SearchToolBar::caseSensitivityChanged);
 
     QShortcut* findNextAction = new QShortcut(QKeySequence("F3"), this);
-    connect(findNextAction, SIGNAL(activated()), this, SLOT(findNext()));
+    connect(findNextAction, &QShortcut::activated, this, &SearchToolBar::findNext);
 
     QShortcut* findPreviousAction = new QShortcut(QKeySequence("Shift+F3"), this);
-    connect(findPreviousAction, SIGNAL(activated()), this, SLOT(findPrevious()));
+    connect(findPreviousAction, &QShortcut::activated, this, &SearchToolBar::findPrevious);
 
     parent->installEventFilter(this);
 }
@@ -113,13 +110,22 @@ void SearchToolBar::caseSensitivityChanged()
     searchText(ui->lineEdit->text());
 }
 
+void SearchToolBar::setText(const QString &text)
+{
+    ui->lineEdit->setText(text);
+}
+
 void SearchToolBar::searchText(const QString &text)
 {
+    m_searchRequests++;
     QPointer<SearchToolBar> guard = this;
     m_view->findText(text, m_findFlags, [=](bool found) {
         if (!guard) {
             return;
         }
+        if (--m_searchRequests != 0) {
+            return;
+        }
         if (ui->lineEdit->text().isEmpty())
             found = true;
 
@@ -141,8 +147,23 @@ bool SearchToolBar::eventFilter(QObject* obj, QEvent* event)
 {
     Q_UNUSED(obj);
 
-    if (event->type() == QEvent::KeyPress && static_cast<QKeyEvent*>(event)->key() == Qt::Key_Escape) {
-        close();
+    if (event->type() == QEvent::KeyPress) {
+        QKeyEvent *ke = static_cast<QKeyEvent*>(event);
+        switch (ke->key()) {
+        case Qt::Key_Escape:
+            close();
+            break;
+        case Qt::Key_Enter:
+        case Qt::Key_Return:
+            if (ke->modifiers() & Qt::ShiftModifier) {
+                findPrevious();
+            } else {
+                findNext();
+            }
+            break;
+        default:
+            break;
+        }
     }
 
     return false;
