@@ -22,6 +22,7 @@
 #include "tabmodel.h"
 #include "webtab.h"
 #include "tabcontextmenu.h"
+#include "browserwindow.h"
 
 #include <QTimer>
 #include <QToolTip>
@@ -200,8 +201,16 @@ bool TabTreeView::viewportEvent(QEvent *event)
         const QModelIndex index = indexAt(me->pos());
         updateIndex(index);
         WebTab *tab = index.data(TabModel::WebTabRole).value<WebTab*>();
-        if (me->buttons() == Qt::MiddleButton && tab) {
-            tab->closeTab();
+        if (me->buttons() == Qt::MiddleButton) {
+            if (tab) {
+                if (isExpanded(index)) {
+                    tab->closeTab();
+                } else {
+                    closeTree(index);
+                }
+            } else {
+                m_window->addTab();
+            }
         }
         if (me->buttons() != Qt::LeftButton) {
             m_pressedIndex = QModelIndex();
@@ -269,6 +278,15 @@ bool TabTreeView::viewportEvent(QEvent *event)
         break;
     }
 
+    case QEvent::MouseButtonDblClick: {
+        QMouseEvent *me = static_cast<QMouseEvent*>(event);
+        const QModelIndex index = indexAt(me->pos());
+        if (me->button() == Qt::LeftButton && !index.isValid()) {
+            m_window->addTab();
+        }
+        break;
+    }
+
     case QEvent::HoverEnter:
     case QEvent::HoverLeave:
     case QEvent::HoverMove: {
@@ -349,7 +367,7 @@ TabTreeView::DelegateButton TabTreeView::buttonAt(const QPoint &pos, const QMode
     return NoButton;
 }
 
-void TabTreeView::addMenuActions(QMenu *menu, const QModelIndex &index) const
+void TabTreeView::addMenuActions(QMenu *menu, const QModelIndex &index)
 {
     if (!m_haveTreeModel) {
         return;
@@ -361,16 +379,10 @@ void TabTreeView::addMenuActions(QMenu *menu, const QModelIndex &index) const
     if (index.isValid() && model()->rowCount(index) > 0) {
         QPersistentModelIndex pindex = index;
         m->addAction(tr("Close Tree"), this, [=]() {
-            QVector<WebTab*> tabs;
-            reverseTraverse(pindex, [&](const QModelIndex &index) {
-                WebTab *tab = index.data(TabModel::WebTabRole).value<WebTab*>();
-                if (tab) {
-                    tabs.append(tab);
-                }
-            });
-            for (WebTab *tab : qAsConst(tabs)) {
-                tab->closeTab();
-            }
+            closeTree(pindex);
+        });
+        m->addAction(tr("Unload Tree"), this, [=]() {
+            unloadTree(pindex);
         });
     }
 
@@ -379,7 +391,7 @@ void TabTreeView::addMenuActions(QMenu *menu, const QModelIndex &index) const
     m->addAction(tr("Collapse All"), this, &TabTreeView::collapseAll);
 }
 
-void TabTreeView::reverseTraverse(const QModelIndex &root, std::function<void(const QModelIndex&)> callback) const
+void TabTreeView::reverseTraverse(const QModelIndex &root, const std::function<void(const QModelIndex&)> &callback) const
 {
     if (!root.isValid()) {
         return;
@@ -389,3 +401,27 @@ void TabTreeView::reverseTraverse(const QModelIndex &root, std::function<void(co
     }
     callback(root);
 }
+
+void TabTreeView::closeTree(const QModelIndex &root)
+{
+    QVector<WebTab*> tabs;
+    reverseTraverse(root, [&](const QModelIndex &index) {
+        WebTab *tab = index.data(TabModel::WebTabRole).value<WebTab*>();
+        if (tab) {
+            tabs.append(tab);
+        }
+    });
+    for (WebTab *tab : qAsConst(tabs)) {
+        tab->closeTab();
+    }
+}
+
+void TabTreeView::unloadTree(const QModelIndex &root)
+{
+    reverseTraverse(root, [&](const QModelIndex &index) {
+        WebTab *tab = index.data(TabModel::WebTabRole).value<WebTab*>();
+        if (tab && tab->isRestored()) {
+            tab->unload();
+        }
+    });
+}
